<?php

define('NOMENCLATURE_OK', 'yes');
define('XML_FILE_NAME', 'content.xml');
define('XML_FILE_TEST_NAME', 'test.xml');
define('XML_FILE', 'includes/' . XML_FILE_NAME);
define('XML_FILE_TEST', 'includes/' . XML_FILE_TEST_NAME);
define('JS_BLANK', "onclick = \"window.open(this.href, '_blank'); return false;\"");
define('ENDLINE', "\n");
define('VAR_XHMTL1', 'xhtml1');
define('VAR_HTML5', 'html5');
define('URL_MEMBER_DVP', 'https://www.developpez.net/forums/member.php?u=');
define('ENCODING_DEFAULT', 'UTF-8');
define('THEME_BLUE', 'blue');

define('XPATH_HEAD', '/root/head');
define('XPATH_CONTENT', '/root/content');
define('XPATH_DATE_GENERIQUE', XPATH_HEAD . '/dates/date[@type="%s"]');
define('XPATH_META_GENERIQUE', XPATH_HEAD . '/meta[@type="%s"]');
define('XPATH_HEAD_TAG_GENERIQUE', XPATH_HEAD . '/%s');
define('XPATH_CONTENT_TAG_GENERIQUE', XPATH_CONTENT . '/%s');
define('XPATH_SECTION', XPATH_CONTENT . '/section');
define('XPATH_ITEM_CV_FIRST', 'item[@title="first"]');
define('XPATH_ITEM_CV', 'item[@title!="first"]');

define('ALIGN_LEFT', 'left');
define('ALIGN_RIGHT', 'right');
define('ALIGN_CENTER', 'center');

$GLOBALS['htmlVersion'] = array(
    'html5' => VAR_HTML5,
    'html 5' => VAR_HTML5,
    'html' => VAR_HTML5,
    'xhtml' => VAR_XHMTL1,
    'xhtml1' => VAR_XHMTL1,
    'xhtml1.0' => VAR_XHMTL1,
    'xhtml 1.0' => VAR_XHMTL1,
    'xhtml1.1' => VAR_XHMTL1,
    'xhtml 1.1' => VAR_XHMTL1,
);

$GLOBALS['versionsBadge'] = array(
    NOMENCLATURE_OK => '1',
    '1' => '1',
    'v1' => '1',
    '2' => '2',
    'v2' => '2',
    '3' => '3',
    'v3' => '3',
);

$GLOBALS['themes'] = array(
    'blue' => THEME_BLUE,
    'BLUE' => THEME_BLUE,
    'bleu' => THEME_BLUE,
    'BLEU' => THEME_BLUE
);

$GLOBALS['alignValues'] = array(
    'center' => ALIGN_CENTER,
    'middle' => ALIGN_CENTER,
    'left' => ALIGN_LEFT,
    'right' => ALIGN_RIGHT
);

$GLOBALS['rest'] = new RestClass();

class XMLDocumentDVP {
    private $xml;

    public function __construct($file) {
        $this->xml = simplexml_load_file($file);
        
        // Corrections possibles du XML (les "&")
        if (!$this->xml){
            $count = null;
            $strXml = (file_get_contents($file));
            do{
                $strXml = XMLDocumentDVP::correctXml($strXml, $count);
            } while ($count > 0);
            $this->xml = simplexml_load_string($strXml);
        }
    }

    public function xpath($xpath) {
        return $this->xml->xpath($xpath);
    }
    
    static function correctXml($str, &$count){
        return preg_replace ("/(^.)*&([^;]*(\\n|\\r\\n|\\n\\r))$/", '$1&amp;$2', $str, -1, $count);
    }

    static function toString($arg) {
        $return = (string) $arg;
        
        $tagsForbid = array(
            'script',
            'object'
        );
        
        foreach($tagsForbid as $tag){
            $return = preg_replace('@<' . $tag . '[^>]*?>.*?</' . $tag . '>@si', "", $return);
        }
        
        return $return;
    }

    static function getXmlFile() {
        return isset($_GET['test']) ? XML_FILE_TEST : XML_FILE;
    }

    static function getXpathValue($xpath, $xml = false) {
        if (!$xml) {
            $xml = new XMLDocumentDVP(self::getXmlFile());
        }
        $xpath = $xml->xpath($xpath);
        return ($xpath) ? XMLDocumentDVP::toString($xpath[0]) : false;
    }

    static function getHeadTagValue($tag) {
        return XMLDocumentDVP::getXpathValue(sprintf(XPATH_HEAD_TAG_GENERIQUE, $tag));
    }

    static function getContentTagValue($tag) {
        return XMLDocumentDVP::getXpathValue(sprintf(XPATH_CONTENT_TAG_GENERIQUE, $tag));
    }
    
    static function getTheme(){
        global $themes;
        $t = XMLDocumentDVP::getContentTagValue('@theme');
        return (isset($themes[$t]) && $themes[$t]) ? "class='" . $themes[$t] . "' " : "";
    }
    
    static function getLogoBadge(){
        global $alignValues;
        
        $retour = array();
        
        if($vbadge = XMLDocumentDVP::getVersionBadge()){
            $retour['vbadge']= $vbadge;
        }
        
        if ($logo = XMLDocumentDVP::getHeadTagValue('logo')){
            $retour['logo']= $logo;
            
            $align = XMLDocumentDVP::getHeadTagValue('logo/@align');
            
            if(!$vbadge && $align && isset($alignValues[strtolower($align)]) && $alignValues[strtolower($align)]){
                $retour['align'] = $alignValues[strtolower($align)];
            }
        }
        
        return $retour;
    }
    
    static function getFavicon(){
        if ($favicon = XMLDocumentDVP::getHeadTagValue('favicon')){
            $favicon = (preg_match("/^http:/", $favicon)) ? $favicon : 'images/' . $favicon;
        }
        return $favicon;
    }
    
    static function getVersionBadge(){
        global $versionsBadge;
        $v = XMLDocumentDVP::getHeadTagValue('iduser/@badge');
        return (isset($versionsBadge[$v]) && $versionsBadge[$v]) ? $versionsBadge[$v] : false;
    }
    
    static function getXHTMLVersion($libelle = false){
        global $htmlVersion;     
        $vHTML = XMLDocumentDVP::getHeadTagValue('xhtml');
        return ($vHTML && isset($htmlVersion[strtolower($vHTML)]) && $htmlVersion[strtolower($vHTML)]) ? (($libelle) ? $vHTML : $htmlVersion[strtolower($vHTML)]) : false;
    }

    static function getDateValue($type) {
        if ($type == 'license') {
            return XMLDocumentDVP::getXpathValue(sprintf(XPATH_DATE_GENERIQUE, $type)) . ' - ' . date('Y');
        } else {
            return XMLDocumentDVP::getXpathValue(sprintf(XPATH_DATE_GENERIQUE, $type));
        }
    }

    static function getMetaValue($type) {
        return XMLDocumentDVP::getXpathValue(sprintf(XPATH_META_GENERIQUE, $type));
    }
    
    static function restResult($url){
    	global $rest;
    	
    	$result = $rest->get($url);
    	 
    	if ($result->code == HTTP_CODE_RESPONSE_SUCCESS){
    		return $result->body;
    	}
    	 
    	return false;
    }
    
    static function getIdRubrique($name){
    	global $rest;
    	
    	$param = array(
    		'idRubrique' => true,
    		'name' =>  $name
    	);
    	
    	$url = $rest->urlServiceRubriques($param);
    	return self::restResult($url);
    }
    
    static function getNameRubrique($id){
    	global $rest;
    	 
    	$param = array(
    		'nameRubrique' => true,
    		'id' =>  $id
    	);
    	 
    	$url = $rest->urlServiceRubriques($param);
    	return self::restResult($url);
    }
    
    static function getSection(){
        $section = XMLDocumentDVP::getHeadTagValue('section');
        $id = false;

        if ($section) {
            if (preg_match("/^[0-9]+$/", $section)){
            	// on vérifie que l'id existe
                if(self::getNameRubrique($section)){
                	$id = $section;
                }
            } else {
                $id = self::getIdRubrique($section);
            }
        }
        
        // Par défaut on prend la section "autres"
        return $id ? $id : self::getIdRubrique('autres');
    }
    
    static function getIdLicence($name){
    	global $rest;
    	
    	$param = array(
    		'idLicence' => true,
    		'name' =>  $name
    	);
    	
    	$url = $rest->urlServiceLicences($param);
    	return self::restResult($url);
    }
    
    static function getNameLicences($id){
    	global $rest;
    	 
    	$param = array(
    		'nameLicence' => true,
    		'id' =>  $id
    	);
    	 
    	$url = $rest->urlServiceRubriques($param);
    	return self::restResult($url);
    }
    
    static function getLicense(){
        $licence = XMLDocumentDVP::getHeadTagValue('license');
        $id = false;
        
        if($licence){
            if (preg_match("/^[0-9]+$/", $licence)) {
            	// on vérifie que l'id existe
            	if(self::getNameLicence($licence)){
            		$id = $licence;
            	}
            } else {
            	$id = self::getIdLicence($licence);
            }
        }
        
        return $id !== false ? $id : self::getIdLicence('none');
    }

    static function getUrlCss(){
        $cssFromXml = XMLDocumentDVP::getHeadTagValue('urlCss');
        return isset($cssFromXml) && $cssFromXml ? $cssFromXml : '/includes/xo_css.css';
    }
}

?>